Re: Not detecting Palm Tungsten T3?



Hi David,

This is almost certainly due to changes in hal that occurred after the
release of gnome-pilot 2.0.15.  This is discussed in gnome bug 484509:
http://bugzilla.gnome.org/show_bug.cgi?id=484509

I'm attaching a patch for gpilotd.c that fixes this issue.  I should
probably go ahead and release a new version of gnome-pilot to fix this
bug, but you could raise this bug in Ubuntu to bring the issue to the
attention of the Ubuntu maintainer.  Debian, for example, patched this
issue last April:
http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=441652

Matt


On Mon, 2008-11-03 at 15:54 -0800, David Liu wrote:
> I'm running Ubuntu 8.10 (Intrepid Ibex), with gnome-pilot 2.0.15, and 
> I'm trying to get my T3 to sync. When I go to System>Preferences>PalmOS 
> Devices (or run gpilotd-control-applet), I get the first-run wizard.
> 
> Device Settings:
> Name: Cradle
> Type: USB
> Timeout: 2
> Device: /dev/pilot
> (Note: I've also tried using the "usb:" device with the same results.)
> Speed: 57600
> "Yes, I've used sync software with this PDA before."
> 
> When it asks me to connect the Palm, I press the button and nothing 
> happens. I can see that /dev/pilot is being created by udev and points 
> to ttyUSB0, but gpilotd just doesn't seem to detect it!
> 
> Relevant dmesg output:
> [ 3610.280012] usb 1-2: new full speed USB device using uhci_hcd and 
> address 17
> [ 3610.451268] usb 1-2: configuration #1 chosen from 1 choice
> [ 3610.459902] visor 1-2:1.0: Handspring Visor / Palm OS converter detected
> [ 3610.460014] usb 1-2: Handspring Visor / Palm OS converter now 
> attached to ttyUSB0
> [ 3610.460067] usb 1-2: Handspring Visor / Palm OS converter now 
> attached to ttyUSB1
> 
> lsmod shows that the "visor" module is loaded.
> 
> I can use pilot-link just fine, by "pilot-xfer -p /dev/pilot -l" after 
> pressing the HotSync button.
> 
> What's going wrong with gnome-pilot?
> 
> Thanks,
> David
> _______________________________________________
> gnome-pilot-list mailing list
> gnome-pilot-list gnome org
> http://mail.gnome.org/mailman/listinfo/gnome-pilot-list
> 

Matt Davey		It's time to invent some new cliches.	
mcdavey mrao cam ac uk 
Index: gpilotd/gpilotd.c
===================================================================
--- gpilotd/gpilotd.c	(revision 1547)
+++ gpilotd/gpilotd.c	(revision 1548)
@@ -1079,7 +1079,7 @@
 hal_device_added (LibHalContext *ctx, const char *udi)
 {
 	gboolean visor_net = FALSE;
-	char *bus, *match_str;
+	char *bus, *platform, *match_str;
 	int vendor_id, product_id, i;
 	GPilotDevice *device;
 	DBusError error;
@@ -1090,15 +1090,23 @@
 
 	load_devices_xml ();
 
 	/* HAL match rule: we look for info.bus == 'usb_device'
 	 * and then try to match the usb_device.product_id and usb_device.vendor_id
 	 * against the list in devices.xml.
 	 */
-	if (!(bus = libhal_device_get_property_string (hal_ctx, udi, "info.bus", NULL)))
+	if (platform = libhal_device_get_property_string (hal_ctx, udi, "pda.platform", NULL)) {
+	    if (strcmp (platform, "palm") != 0) {
+		libhal_free_string (platform);
 		return;
-	if (strcmp (bus, "usb_device") != 0) {
+	    }
+	} else if (bus = libhal_device_get_property_string (hal_ctx, udi, "info.bus", NULL)) {
+	    if (strcmp (bus, "usb_device") != 0) {
 		libhal_free_string (bus);
 		return;
+	    }
+	} else {
+	    return;
 	}
 
 	dbus_error_init (&error);
@@ -1090,15 +1090,23 @@
 	load_devices_xml ();
 
-	/* HAL match rule: we look for info.bus == 'usb_device'
+	/* HAL match rule: we look for pda.platform == 'palm'
+	 * (or the legacy info.bus == 'usb_device')
 	 * and then try to match the usb_device.product_id and usb_device.vendor_id
 	 * against the list in devices.xml.


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]